import {Button, Divider, Form, Input, Radio, Space} from "antd";
import {useState} from "react";

type FormFieldType = {
    invoiceTitle: string;
    invoiceNo: number;
    invoiceAddress: string;
    invoicePhone: string;
    invoiceAccount: string;
    invoiceBank: string;
    content: string;
    rate: string;
    type: string;
}

export default function InvoiceSave() {
    const [form] = Form.useForm<FormFieldType>();
    const [isSaveInvoiceInfo, setIsSaveInvoiceInfo] = useState(0);

    return (
        <>
            <Form
                name="basic"
                initialValues={{remember: true}}
                form={form}
            >
                <Divider orientation="left" plain>开票信息</Divider>
                <table className="pay-table">
                    <colgroup>
                        <col width="120"/>
                        <col/>
                    </colgroup>
                    <tbody>
                    <tr>
                        <td className="table-label">公司名称 *</td>
                        <td>
                            <Form.Item
                                name="invoiceTitle"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入公司名称'}]}
                            >
                                <Input placeholder="请输入公司名称"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">纳税人识别号 *</td>
                        <td>
                            <Form.Item
                                name="invoiceNo"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入纳税人识别号'}]}
                            >
                                <Input placeholder="请输入纳税人识别号"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">公司地址 *</td>
                        <td>
                            <Form.Item
                                name="invoiceAddress"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入公司地址'}]}
                            >
                                <Input placeholder="请输入公司地址"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">联系电话 *</td>
                        <td>
                            <Form.Item
                                name="invoicePhone"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入联系电话'}]}
                            >
                                <Input placeholder="请输入联系电话"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">开户行 *</td>
                        <td>
                            <Form.Item
                                name="invoiceAccount"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入开户行'}]}
                            >
                                <Input placeholder="请输入开户行"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">开户行账号 *</td>
                        <td>
                            <Form.Item
                                name="invoiceBank"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入开户行账号'}]}
                            >
                                <Input placeholder="请输入开户行账号"/>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">开票内容 *</td>
                        <td>
                            <Form.Item
                                name="content"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请选择开票内容'}]}
                            >
                                <Radio.Group>
                                    <Space direction="vertical">
                                        <Radio value={1}>A</Radio>
                                        <Radio value={2}>B</Radio>
                                        <Radio value={3}>C</Radio>
                                        <Radio value={4}>D</Radio>
                                    </Space>
                                </Radio.Group>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">开票税率 *</td>
                        <td>
                            <Form.Item
                                name="rate"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请选择开票税率'}]}
                            >
                                <Radio.Group>
                                    <Radio value={1}>A</Radio>
                                    <Radio value={2}>B</Radio>
                                    <Radio value={3}>C</Radio>
                                    <Radio value={4}>D</Radio>
                                </Radio.Group>
                            </Form.Item>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">发票类型 *</td>
                        <td>
                            <Form.Item
                                name="type"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请选择发票类型'}]}
                            >
                                <Radio.Group>
                                    <Radio value={1}>A</Radio>
                                    <Radio value={2}>B</Radio>
                                    <Radio value={3}>C</Radio>
                                    <Radio value={4}>D</Radio>
                                </Radio.Group>
                            </Form.Item>
                        </td>
                    </tr>

                    <tr>
                        <td className="table-label">保存开票信息 *</td>
                        <td>
                            <Radio.Group defaultValue={isSaveInvoiceInfo} onChange={(e) => {
                                setIsSaveInvoiceInfo(e.target.value)
                            }}>
                                <Radio value={0}>否</Radio>
                                <Radio value={1}>是</Radio>
                            </Radio.Group>
                        </td>
                    </tr>
                    </tbody>
                </table>
                <Divider orientation="left" plain>开票内容</Divider>
                <table className="pay-table">
                    <colgroup>
                        <col width="120"/>
                        <col/>
                    </colgroup>
                    <tbody>
                    <tr>
                        <td className="table-label">开票金额 *</td>
                        <td>
                            <div>
                                <span>￥</span>
                                <span style={{fontSize: '20px', fontWeight: 'bold'}}>300</span>
                                <Button type="link" size="small">请选择需要开票的订单</Button>
                            </div>
                        </td>
                    </tr>
                    <tr>
                        <td className="table-label">开票备注</td>
                        <td>
                            <Form.Item
                                name="invoiceBank"
                                style={{marginBottom: '0'}}
                                rules={[{required: true, message: '请输入开票备注'}]}
                            >
                                <Input.TextArea placeholder="请输入开票备注" rows={4}/>
                            </Form.Item>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </Form>
        </>
    );
}