import './menu-tree-with-top-button.css';
import MenuTree from "./MenuTree.tsx";
import {IMenuTreeItem} from "../../interfaces/menu/IMenuTree.ts";
import {useContext, useEffect, useState} from "react";
import {del, get, post, put} from "../../util/AjaxUtils.ts";
import useMessage from "antd/es/message/useMessage";
import {IndexListDataType, IndexListDispatchContext,} from "../../context/IndexListContext.ts";
import {MenuProps} from "antd";


type ProjCategoryDTO = {
    projCategoryId: string;
    projCategoryParentId: string;
    projCategoryParentName: string;
    isParent: boolean;
    projCategoryName: string;
    projCategoryCode: string;

    subProjCategory: ProjCategoryDTO[];
}

class MenuTreeItem implements IMenuTreeItem {
    children: Array<IMenuTreeItem> | null;
    id: string;
    pId: string;
    level: number;
    isEdit: boolean;
    isOpen: boolean;
    isParent: boolean;
    name: string;
    oldName: string;

    constructor(id: string, pId: string, name: string, level: number) {
        this.id = id;
        this.pId = pId;
        this.level = level;
        this.name = name;
        this.oldName = name;
        this.isEdit = false;
        this.isOpen = false;
        this.isParent = false;
        this.children = null;
    }

}

export default function MenuTreeWithTopButton() {
    const indexListDispatchContext = useContext(IndexListDispatchContext);

    const [messageApi, messageContext] = useMessage();
    const menuTrees: Array<IMenuTreeItem> = [];
    const [menuTreeArray, setMenuTreeArray] = useState(menuTrees);
    const newCategoryName: string = '新目录';

    const menuArray = (datas: ProjCategoryDTO[], level: number) => {
        const menus: MenuTreeItem[] = [];
        datas.forEach((item) => {
            const menu = new MenuTreeItem(item.projCategoryId, item.projCategoryParentId, item.projCategoryName, level);
            if (item.subProjCategory && item.subProjCategory.length > 0) {
                menu.isParent = true;
                menu.children = menuArray(item.subProjCategory, level + 1);
            }
            menus.push(menu);
        })
        return menus;
    }

    const menus2Dropdowns = (datas: MenuTreeItem[] | null) => {
        if (!datas) {
            return;
        }
        const dropdowns: MenuProps['items'] = [];
        datas.forEach((item) => {
            const children = menus2Dropdowns(item.children);
            dropdowns.push({
                key: item.id,
                label: item.name,
                title: item.name,
                children: children
            })
        })
        return dropdowns;
    }

    useEffect(() => {
        get<ProjCategoryDTO[]>({
            messageApi,
            url: '/api/proj/category/listallbyparentid/0',
            onSuccess({data}) {
                const menus = menuArray(data, 1);
                setMenuTreeArray(menus);
                indexListDispatchContext({
                    type: IndexListDataType.CATEGORY,
                    value: menus2Dropdowns(menus)
                })
            }
        })
    }, []);

    return (
        <>
            <div className="menu-tree-with-top-button">
                <button type="button" className="btn btn-orange" onClick={() => {
                    // 新增
                    post<any>({
                        messageApi,
                        url: '/api/proj/category/save',
                        body: {
                            projCategoryParentId: '0',
                            projCategoryName: newCategoryName
                        },
                        onSuccess({data}) {
                            const menuTreeItem = new MenuTreeItem(`${data.data}`, '0', newCategoryName, 1);
                            menuTreeItem.isParent = false;
                            menuTreeArray.push(menuTreeItem);
                            setMenuTreeArray([...menuTreeArray]);
                            indexListDispatchContext({
                                type: IndexListDataType.CATEGORY,
                                value: menus2Dropdowns(menuTreeArray)
                            })
                        }
                    })
                }}>添加目录
                </button>
                <MenuTree
                    menus={menuTreeArray}
                    url={''}
                    setMenuTreeArray={() => {
                        setMenuTreeArray([
                            ...menuTreeArray
                        ])
                    }}
                    handleClick={(item) => {
                        const isActive = item.active;
                        menuTreeArray.forEach(item => item.active = false);
                        if(!isActive) {
                            item.active = true;
                        }
                        setMenuTreeArray([
                            ...menuTreeArray
                        ])
                        indexListDispatchContext({
                            type: IndexListDataType.CATEGORY_CHANGE,
                            value: item.active ? item.id : ''
                        })
                        console.log(item)
                    }}
                    handleExpand={() => {
                    }}
                    handleAddClick={(item) => {
                        post<any>({
                            messageApi,
                            url: '/api/proj/category/save',
                            body: {
                                projCategoryParentId: item.id,
                                projCategoryName: newCategoryName
                            },
                            onSuccess({data}) {
                                item.isParent = true;
                                item.isOpen = true;
                                if (!item.children) {
                                    item.children = new Array<IMenuTreeItem>();
                                }
                                const menuTreeItem = new MenuTreeItem(`${data.data}`, item.id, newCategoryName, item.level + 1);
                                menuTreeItem.isParent = false;
                                item.children.push(menuTreeItem);
                                setMenuTreeArray([
                                    ...menuTreeArray
                                ])
                                indexListDispatchContext({
                                    type: IndexListDataType.CATEGORY,
                                    value: menus2Dropdowns(menuTreeArray)
                                })
                            }
                        })
                    }}
                    handleEditClick={(item) => {
                        item.isEdit = true;
                        setMenuTreeArray([
                            ...menuTreeArray
                        ])
                    }}
                    handleRemoveClick={(item, index, parent) => {
                        del<any>({
                            messageApi,
                            url: `/api/proj/category/delete/${item.id}`,
                            onSuccess() {
                                if (parent) {
                                    parent?.children?.splice(index, 1);
                                } else {
                                    menuTreeArray.splice(index, 1);
                                }
                                setMenuTreeArray([
                                    ...menuTreeArray
                                ])
                                indexListDispatchContext({
                                    type: IndexListDataType.CATEGORY_DELETE,
                                    value: menus2Dropdowns(menuTreeArray)
                                })
                            }
                        })
                    }}
                    handleEditSaveClick={(item) => {
                        // 这里发请求，成功之后修改，失败还原
                        if (item.name === '') {
                            return;
                        }
                        put<any>({
                            messageApi,
                            url: `/api/proj/category/update/${item.id}`,
                            body: {
                                projCategoryParentId: item.pId,
                                projCategoryName: item.name
                            },
                            onSuccess() {
                                item.oldName = item.name;
                                item.isEdit = false;
                                setMenuTreeArray([
                                    ...menuTreeArray
                                ])
                                indexListDispatchContext({
                                    type: IndexListDataType.CATEGORY,
                                    value: menus2Dropdowns(menuTreeArray)
                                })
                            }
                        })
                    }}
                    handleEditCancelClick={(item) => {
                        item.name = item.oldName;
                        item.isEdit = false;
                        setMenuTreeArray([
                            ...menuTreeArray
                        ])
                    }}
                    handleNameChange={(item) => {
                        indexListDispatchContext({
                            type: IndexListDataType.CATEGORY_CHANGE,
                            value: item.id
                        })
                    }}
                />
            </div>
            {messageContext}
        </>
    )
}